@@ -32,6 +32,7 @@ class Safe_configuration_class
     const CFG_LINK = 'link';
     const CFG_UNLINK = 'unlink';
     const CFG_NONE = 'none';
+    const CFG_LOAD = 'load';
     private $_action;
     // Configuration type enumeration
     const CFG_FILE = 'file';
@@ -409,6 +410,11 @@ class Safe_configuration_manager_class extends Safe_object_class
                         // Delete all record
                         $success = $data['db_class']->empty_table($fname);
                         break;
+
+                    case Safe_configuration_class::CFG_LOAD:
+                        // Load data to DB
+                        $success = $data['db_class']->load_data($fname, $data['data']);
+                        break;
                     }
                     if (true != $success) $display_action = $fname . " - " . $data['db_class']->_error_message();
                     // Disconnect from database
