@@ -1225,11 +1225,15 @@ class Sng_config_manager extends Safe_CI_Controller
             $_create_type = null;
             if($_POST['profile-type']){
                 $_create_type = $_POST['profile-type'];
+            }else if($sub_type && $sub_name){
+                $_create_type = $sub_type;
+            }else{
+                $_create_type = $obj_type;
             }
             if($sub_type && $sub_name){
-                $cfg_obj = $module->create_aggregate_object((isset($_create_type))?$_create_type:$sub_type, $sub_name);
+                $cfg_obj = $module->create_aggregate_object($_create_type, $sub_name);
             } else {
-                $cfg_obj = $module->create_aggregate_object((isset($_create_type))?$_create_type:$obj_type, $obj_name);
+                $cfg_obj = $module->create_aggregate_object($_create_type, $obj_name);
             }
             if($cfg_obj->has_aggregate_objects()){
                 $redirect_url = '/modify/'.$module_name.'/'.$obj_type.'/'.$obj_name;
@@ -1239,13 +1243,13 @@ class Sng_config_manager extends Safe_CI_Controller
             $new_obj = true;
             if(isset($post_data['src']) ){
                 // Copy from another profile
-                $src_obj =  $aggr_obj[$post_data['src']];
+                $src_obj =  $module->get_aggregate_object($_create_type, $post_data['src']);
                 if($src_obj){
                     $cfg_obj->set_data_values($src_obj->get_data_values(false));
                 }
             }elseif(isset($_POST['src'])){
                 //for copy sub objs in save
-                $src_obj =  $aggr_obj[$_POST['src']];
+                $src_obj =  $module->get_aggregate_object($_create_type, $_POST['src']);
                 unset($_POST['src']);
             }
         }
