@@ -349,7 +349,7 @@ class Sng_rest extends REST_Controller
                     $agg_objs = $module->has_aggregate_objects();
                     if($agg_objs && isset($agg_objs[$obj_type])){
                         //pass pagination/limit and pagination/offset in $data
-                        $objs = $module->get_aggregate_objects($obj_type, false, $data);
+                        $objs = $module->get_aggregate_objects_keys($obj_type, false, $data);
                         //check if support pagination
                         if($agg_objs[$obj_type]['pagination']){
                             $response_data['count'] = count($objs['data']);
@@ -360,7 +360,7 @@ class Sng_rest extends REST_Controller
                             $response_data['pagination'] = true;
                         }else{
                             $response_data['count'] = count($objs);
-                            $response_data['data'] = array_keys($objs);
+                            $response_data['data'] = $objs;
                         }
                         $has_obj = true;
                     }
